//
//  ConnectionView.swift
//  RemoteAccess
//
//  Created by Paweł Leśniewski on 18/11/2024.
//

import SwiftUI
import LiveKit
import Combine

struct ConnectionView: View {

    @State private var url: String = ""
    @State private var token: String = ""
    
    @ObservedObject var viewModel: ViewModel

    var body: some View {
        VStack(spacing: 20) {
            Text("Connect with server")
                .font(.title)
                .padding()

            TextField("URL", text: $url)
                .autocorrectionDisabled()
                .textFieldStyle(RoundedBorderTextFieldStyle())
                .padding()
                .disableAutocorrection(true)

            TextField("Token", text: $token)
                .textFieldStyle(RoundedBorderTextFieldStyle())
                .padding()
                .disableAutocorrection(true)

            Button(action: {
                connectToRoom(url: url, token: token)
            }) {
                Text("Connect")
                    .font(.headline)
                    .frame(maxWidth: .infinity)
                    .padding()
                    .background(Color.blue)
                    .foregroundColor(.white)
                    .cornerRadius(10)
            }
            .padding()

            Spacer()
        }
        .padding()
    }

    func connectToRoom(url: String, token: String) {
        print("URL: \(url)")
        print("Token: \(token)")
        
        self.viewModel.initializeNewSession(url: self.url, token: self.token)
        
    }
}

struct ConnectionView_Previews: PreviewProvider {
    static var previews: some View {
        ConnectionView(viewModel: .init())
    }
}
